==> server-core-3.6.2-sources.jar: com/xebialabs/deployit/security/PermissionDeniedException.java <==
package com.xebialabs.deployit.security;

import com.xebialabs.deployit.exception.DeployitException;
import com.xebialabs.deployit.exception.HttpResponseCodeResult;
import com.xebialabs.deployit.security.permission.Permission;

import java.util.List;

/**
 */
@SuppressWarnings("serial")
@HttpResponseCodeResult(statusCode = 403)
public class PermissionDeniedException extends DeployitException {

	public PermissionDeniedException(final String message, final Exception cause) {
		super(cause, message);
	}

	public PermissionDeniedException() {
		super();
	}

	public PermissionDeniedException(final String message) {
		super(message);
	}

	public static PermissionDeniedException withMessage(final String message, final Exception cause) {
		return new PermissionDeniedException(message, cause);
	}
	public static PermissionDeniedException withMessage(final String message) {
		return new PermissionDeniedException(message);
	}

	public static PermissionDeniedException forNodeAndPrivilege(final String id, final String privilege) {
		final PermissionDeniedException deniedException = new PermissionDeniedException();
		deniedException.add("%s privilege on %s is not granted to you", privilege, id);
		return deniedException;
	}

	public static PermissionDeniedException forPermission(Permission permission, List<String> onConfigurationItems) {
		final PermissionDeniedException deniedException = new PermissionDeniedException();
		deniedException.add("Permission %s on %s is not granted to you", permission, onConfigurationItems);
		return deniedException;
	}
}

==> server-core-3.7.4-sources.jar: com/xebialabs/deployit/security/PermissionDeniedException.java <==
package com.xebialabs.deployit.security;

import com.xebialabs.deployit.exception.DeployitException;
import com.xebialabs.deployit.exception.HttpResponseCodeResult;
import com.xebialabs.deployit.security.permission.Permission;

import java.util.List;

/**
 */
@SuppressWarnings("serial")
@HttpResponseCodeResult(statusCode = 403)
public class PermissionDeniedException extends DeployitException {

	public PermissionDeniedException(final String message, final Exception cause) {
		super(cause, message);
	}

	public PermissionDeniedException() {
		super();
	}

	public PermissionDeniedException(final String message) {
		super(message);
	}

	public static PermissionDeniedException withMessage(final String message, final Exception cause) {
		return new PermissionDeniedException(message, cause);
	}
	public static PermissionDeniedException withMessage(final String message) {
		return new PermissionDeniedException(message);
	}

	public static PermissionDeniedException forNodeAndPrivilege(final String id, final String privilege) {
		final PermissionDeniedException deniedException = new PermissionDeniedException();
		deniedException.add("%s privilege on %s is not granted to you", privilege, id);
		return deniedException;
	}

	public static PermissionDeniedException forPermission(Permission permission, List<String> onConfigurationItems) {
		final PermissionDeniedException deniedException = new PermissionDeniedException();
		deniedException.add("Permission %s on %s is not granted to you", permission, onConfigurationItems);
		return deniedException;
	}

	public static PermissionDeniedException forPermission(Permission permission, String onConfigurationItem) {
		final PermissionDeniedException deniedException = new PermissionDeniedException();
		if (onConfigurationItem == null) {
			deniedException.add("Permission %s is not granted to you", permission);
		} else {
			deniedException.add("Permission %s on %s is not granted to you", permission, onConfigurationItem);
		}
		return deniedException;
	}
}
